@@ -25,7 +25,8 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 #include <gnuastro/fits.h>
 #include <gnuastro/linkedlist.h>
-#include <gnuastro/commonparams.h>
+
+#include <commonparams.h>
 
 /* Progarm name macros: */
 #define SPACK           "astarithmetic"   /* Subpackage executable name. */
