@@ -33,10 +33,11 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 #include <gnuastro/fits.h>
 #include <gnuastro/array.h>
-#include <gnuastro/timing.h>     /* Includes time.h and sys/time.h */
-#include <gnuastro/checkset.h>
 #include <gnuastro/statistics.h>
-#include <gnuastro/configfiles.h>
+
+#include <timing.h>              /* Includes time.h and sys/time.h */
+#include <checkset.h>
+#include <configfiles.h>
 
 #include "main.h"
 
