@@ -33,9 +33,10 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 #include <gnuastro/box.h>
 #include <gnuastro/fits.h>
-#include <gnuastro/timing.h>
 #include <gnuastro/polygon.h>
-#include <gnuastro/checkset.h>
+
+#include <timing.h>
+#include <checkset.h>
 
 #include "main.h"
 
