@@ -32,12 +32,13 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <gnuastro/box.h>
 #include <gnuastro/fits.h>
 #include <gnuastro/array.h>
-#include <gnuastro/timing.h>
 #include <gnuastro/threads.h>
-#include <gnuastro/checkset.h>
 #include <gnuastro/txtarray.h>
 #include <gnuastro/statistics.h>
 
+#include <timing.h>
+#include <checkset.h>
+
 #include "main.h"
 
 #include "mkprof.h"             /* Needs main.h astrthreads.h */
