@@ -30,7 +30,8 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 #include <gnuastro/fits.h>
 #include <gnuastro/array.h>
-#include <gnuastro/timing.h>
+
+#include <timing.h>
 
 #include "main.h"
 
