@@ -38,6 +38,148 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 
 
+/****************************************************************
+ *****************            Float          ********************
+ ****************************************************************/
+void
+gal_linkedlist_print_fll_array(struct gal_linkedlist_fll **afll, size_t num)
+{
+  size_t i;
+  struct gal_linkedlist_fll *tmp;
+  for(i=0;i<num;++i)
+    {
+      printf(" %lu:\n", i);
+      for(tmp=afll[i];tmp!=NULL;tmp=tmp->next)
+        printf("%f, ", tmp->v);
+      printf("\n");
+    }
+}
+
+
+
+
+
+void
+gal_linkedlist_add_to_fll(struct gal_linkedlist_fll **list, float value)
+{
+  struct gal_linkedlist_fll *newnode;
+
+  errno=0;
+  newnode=malloc(sizeof *newnode);
+  if(newnode==NULL)
+    error(EXIT_FAILURE, errno, "linkedlist: New element in "
+          "gal_linkedlist_fll");
+
+  newnode->v=value;
+  newnode->next=*list;
+  *list=newnode;
+}
+
+
+
+
+
+void
+gal_linkedlist_pop_from_fll(struct gal_linkedlist_fll **list, float *value)
+{
+  struct gal_linkedlist_fll *tmp;
+  tmp=*list;
+  *value=tmp->v;
+  *list=tmp->next;
+  free(tmp);
+}
+
+
+
+
+
+size_t
+gal_linkedlist_num_in_fll(struct gal_linkedlist_fll *list)
+{
+  size_t num=0;
+  struct gal_linkedlist_fll *tmp;
+  for(tmp=list;tmp!=NULL;tmp=tmp->next)
+    ++num;
+  return num;
+}
+
+
+
+
+
+void
+gal_linkedlist_fll_to_array(struct gal_linkedlist_fll *list,
+                            float **f, size_t *num)
+{
+  float *tf;
+  size_t i=0;
+  struct gal_linkedlist_fll *tmp;
+
+  /* Find the number of elements: */
+  if(*num==0)
+    *num=gal_linkedlist_num_in_fll(list);
+
+  /* Allocate the space: */
+  errno=0;
+  *f=malloc(*num*sizeof(float));
+  if(*f==NULL)
+    error(EXIT_FAILURE, errno, "linkedlist: array of gal_linkedlist_fll "
+          "with %lu elements", *num);
+  tf=*f;
+
+  /* Fill in the array: */
+  for(tmp=list;tmp!=NULL;tmp=tmp->next)
+    tf[i++]=tmp->v;
+}
+
+
+
+
+
+void
+gal_linkedlist_free_fll(struct gal_linkedlist_fll *list)
+{
+  struct gal_linkedlist_fll *tmp, *ttmp;
+  tmp=list;
+  while(tmp!=NULL)
+    {
+      ttmp=tmp->next;
+      free(tmp);
+      tmp=ttmp;
+    }
+}
+
+
+
+
+
+void
+gal_linkedlist_free_fll_array(struct gal_linkedlist_fll **afll, size_t num)
+{
+  size_t i;
+  for(i=0;i<num;++i)
+    gal_linkedlist_free_fll(afll[i]);
+  free(afll);
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 /****************************************************************
  *****************        Two doubles        ********************
@@ -160,149 +302,6 @@ gal_linkedlist_free_tdll(struct gal_linkedlist_tdll *list)
 
 
 
-/****************************************************************
- *****************            Float          ********************
- ****************************************************************/
-void
-gal_linkedlist_print_fll_array(struct gal_linkedlist_fll **afll, size_t num)
-{
-  size_t i;
-  struct gal_linkedlist_fll *tmp;
-  for(i=0;i<num;++i)
-    {
-      printf(" %lu:\n", i);
-      for(tmp=afll[i];tmp!=NULL;tmp=tmp->next)
-	printf("%f, ", tmp->v);
-      printf("\n");
-    }
-}
-
-
-
-
-
-void
-gal_linkedlist_add_to_fll(struct gal_linkedlist_fll **list, float value)
-{
-  struct gal_linkedlist_fll *newnode;
-
-  errno=0;
-  newnode=malloc(sizeof *newnode);
-  if(newnode==NULL)
-    error(EXIT_FAILURE, errno, "linkedlist: New element in "
-          "gal_linkedlist_fll");
-
-  newnode->v=value;
-  newnode->next=*list;
-  *list=newnode;
-}
-
-
-
-
-
-void
-gal_linkedlist_pop_from_fll(struct gal_linkedlist_fll **list, float *value)
-{
-  struct gal_linkedlist_fll *tmp;
-  tmp=*list;
-  *value=tmp->v;
-  *list=tmp->next;
-  free(tmp);
-}
-
-
-
-
-
-size_t
-gal_linkedlist_num_in_fll(struct gal_linkedlist_fll *list)
-{
-  size_t num=0;
-  struct gal_linkedlist_fll *tmp;
-  for(tmp=list;tmp!=NULL;tmp=tmp->next)
-    ++num;
-  return num;
-}
-
-
-
-
-
-void
-gal_linkedlist_fll_to_array(struct gal_linkedlist_fll *list,
-                            float **f, size_t *num)
-{
-  float *tf;
-  size_t i=0;
-  struct gal_linkedlist_fll *tmp;
-
-  /* Find the number of elements: */
-  if(*num==0)
-    *num=gal_linkedlist_num_in_fll(list);
-
-  /* Allocate the space: */
-  errno=0;
-  *f=malloc(*num*sizeof(float));
-  if(*f==NULL)
-    error(EXIT_FAILURE, errno, "linkedlist: array of gal_linkedlist_fll "
-          "with %lu elements", *num);
-  tf=*f;
-
-  /* Fill in the array: */
-  for(tmp=list;tmp!=NULL;tmp=tmp->next)
-    tf[i++]=tmp->v;
-}
-
-
-
-
-
-void
-gal_linkedlist_free_fll(struct gal_linkedlist_fll *list)
-{
-  struct gal_linkedlist_fll *tmp, *ttmp;
-  tmp=list;
-  while(tmp!=NULL)
-    {
-      ttmp=tmp->next;
-      free(tmp);
-      tmp=ttmp;
-    }
-}
-
-
-
-
-
-void
-gal_linkedlist_free_fll_array(struct gal_linkedlist_fll **afll, size_t num)
-{
-  size_t i;
-  for(i=0;i<num;++i)
-    gal_linkedlist_free_fll(afll[i]);
-  free(afll);
-}
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 /****************************************************************
  *****************           string          ********************
  ****************************************************************/
@@ -398,14 +397,15 @@ gal_linkedlist_num_in_stll(struct gal_linkedlist_stll *list)
  *****************           size_t          ********************
  ****************************************************************/
 void
-add_to_sll(struct gal_linkedlist_sll **list, size_t value)
+gal_linkedlist_add_to_sll(struct gal_linkedlist_sll **list, size_t value)
 {
   struct gal_linkedlist_sll *newnode;
 
   errno=0;
   newnode=malloc(sizeof *newnode);
   if(newnode==NULL)
-    error(EXIT_FAILURE, errno, "linkedlist: New element in gal_linkedlist_sll");
+    error(EXIT_FAILURE, errno,
+          "linkedlist: New element in gal_linkedlist_sll");
 
   newnode->v=value;
   newnode->next=*list;
@@ -417,7 +417,7 @@ add_to_sll(struct gal_linkedlist_sll **list, size_t value)
 
 
 void
-pop_from_sll(struct gal_linkedlist_sll **list, size_t *value)
+gal_linkedlist_pop_from_sll(struct gal_linkedlist_sll **list, size_t *value)
 {
   struct gal_linkedlist_sll *tmp;
   tmp=*list;
@@ -431,7 +431,7 @@ pop_from_sll(struct gal_linkedlist_sll **list, size_t *value)
 
 
 size_t
-numinsll(struct gal_linkedlist_sll *list)
+gal_linkedlist_num_in_sll(struct gal_linkedlist_sll *list)
 {
   size_t num=0;
   struct gal_linkedlist_sll *tmp;
@@ -446,22 +446,27 @@ numinsll(struct gal_linkedlist_sll *list)
 
 void
 gal_linkedlist_sll_to_array(struct gal_linkedlist_sll *list,
-                            size_t **f, size_t *num)
+                            size_t **s, size_t *num, int inverse)
 {
-  size_t i=0, *tf;
+  size_t i, *ts;
   struct gal_linkedlist_sll *tmp;
 
-  *num=numinsll(list);
+  *num=gal_linkedlist_num_in_sll(list);
 
   errno=0;
-  *f=malloc(*num*sizeof(size_t));
-  if(*f==NULL)
+  *s=malloc(*num*sizeof(size_t));
+  if(*s==NULL)
     error(EXIT_FAILURE, errno, "linkedlist: array of gal_linkedlist_sll "
           "with %lu elements", *num);
-  tf=*f;
+  ts=*s;
 
-  for(tmp=list;tmp!=NULL;tmp=tmp->next)
-    tf[i++]=tmp->v;
+  i = inverse ? *num-1: 0;
+  if(inverse)
+    for(tmp=list;tmp!=NULL;tmp=tmp->next)
+      ts[i--]=tmp->v;
+  else
+    for(tmp=list;tmp!=NULL;tmp=tmp->next)
+      ts[i++]=tmp->v;
 }
 
 
@@ -515,67 +520,6 @@ gal_linkedlist_free_sll(struct gal_linkedlist_sll *list)
 
 
 
-/****************************************************************
- ******************        Two way SLL    ***********************
- *****************           size_t          ********************
- ****************************************************************/
-
-void
-gal_linkedlist_add_to_tsll_end(struct gal_linkedlist_tsll **last, size_t value)
-{
-  struct gal_linkedlist_tsll *newnode;
-
-  errno=0;
-  newnode=malloc(sizeof *newnode);
-  if(newnode==NULL)
-    error(EXIT_FAILURE, errno, "linkedlist: New element in "
-          "gal_linkedlist_tsll");
-
-  newnode->v=value;
-  newnode->next=*last;
-  newnode->prev=NULL;
-  if(*last)			/* If *list is not NULL */
-    (*last)->prev=newnode;
-  *last=newnode;
-}
-
-
-
-
-
-/* Note that start has to be initialized. */
-void
-gal_linkedlist_pop_from_tsll_start(struct gal_linkedlist_tsll **first,
-                                   size_t *value)
-{
-  struct gal_linkedlist_tsll *tmp;
-  tmp=*first;
-  *value=tmp->v;
-  *first=tmp->prev;
-  free(tmp);
-  if(*first)
-    (*first)->next=NULL;
-}
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 /****************************************************************
  ******************        Ordered SLL       ********************
  *****************           size_t          ********************
@@ -602,21 +546,21 @@ gal_linkedlist_add_to_osll(struct gal_linkedlist_osll **list,
     {
       if(tosort<tmp->s) break;
       /* No need for else, it will only come here if the condition
-	 above is not satisfied. */
+         above is not satisfied. */
       prev=tmp;
       tmp=tmp->next;
     }
 
-  if(tmp==NULL)	     /* This is the largest value so far. */
-    {		     /* '*list' only changes if it is NULL. */
+  if(tmp==NULL)      /* This is the largest value so far. */
+    {                /* '*list' only changes if it is NULL. */
       newnode->next=NULL;
       if(prev) prev->next=newnode;   /* 'prev' is not NULL! */
-      else     *list=newnode;	     /* Only for initial node. */
+      else     *list=newnode;        /* Only for initial node. */
     }
   else
     {
       if(prev) prev->next=newnode;
-      else     *list=newnode;	/* 'tosort' is smaller than all. */
+      else     *list=newnode;        /* 'tosort' is smaller than all. */
       newnode->next=tmp;
     }
 }
@@ -651,7 +595,7 @@ gal_linkedlist_osll_into_sll(struct gal_linkedlist_osll *in,
   while(in!=NULL)
     {
       tmp=in->next;
-      add_to_sll(out, in->v);
+      gal_linkedlist_add_to_sll(out, in->v);
       free(in);
       in=tmp;
     }
@@ -687,23 +631,23 @@ gal_linkedlist_osll_into_sll(struct gal_linkedlist_osll *in,
             |
    NULL <-- (v0,s0) <--> (v1,s1) <--> ... (vn,sn) --> NULL
                                           |
-			   smallest pointer
+                           smallest pointer
 
    Where s(n)>s(n+1) for all n.
 */
 
 void
-gal_linkedlist_print_tosll(struct gal_linkedlist_tosll *l,
-                           struct gal_linkedlist_tosll *s)
+gal_linkedlist_print_tosll(struct gal_linkedlist_tosll *largest,
+                           struct gal_linkedlist_tosll *smallest)
 {
   size_t counter=1;   /* We are not counting array elements :-D ! */
-  while(l!=NULL)
+  while(largest!=NULL)
     {
       printf("\t%-5lu (%lu, %.4f) \n", counter++,
-	     l->v, l->s);
-      l=l->next;
-      printf("\t\t\t\t(%lu, %.4f)\n", s->v, s->s);
-      s=s->prev;
+             largest->v, largest->s);
+      largest=largest->next;
+      printf("\t\t\t\t(%lu, %.4f)\n", smallest->v, smallest->s);
+      smallest=smallest->prev;
     }
   printf("\n");
 }
@@ -734,32 +678,32 @@ gal_linkedlist_add_to_tosll_end(struct gal_linkedlist_tosll **largest,
     {
       if(tosort >= tmp->s) break;
       /* No need for else, it will only come here if the condition
-	 above is not satisfied. */
+         above is not satisfied. */
       newnode->prev=tmp;
       tmp=tmp->next;
     }
 
-  if(tmp==NULL)	     /* This is the smallest value so far.     */
-    {		     /* '*largest' only changes if it is NULL. */
+  if(tmp==NULL)      /* This is the smallest value so far.     */
+    {                /* '*largest' only changes if it is NULL. */
       newnode->next=NULL;
       *smallest=newnode;
-      if(newnode->prev)		/* 'prev' is not NULL! */
-	newnode->prev->next=newnode;
-      else			/* 'prev is NULL, Only first. */
-	*largest=newnode;
+      if(newnode->prev)         /* 'prev' is not NULL! */
+        newnode->prev->next=newnode;
+      else                      /* 'prev is NULL, Only first. */
+        *largest=newnode;
     }
   else
     {
       if(newnode->prev)
-	{
-	  newnode->prev->next->prev=newnode;
-	  newnode->prev->next=newnode;
-	}
+        {
+          newnode->prev->next->prev=newnode;
+          newnode->prev->next=newnode;
+        }
       else
-	{
-	  (*largest)->prev=newnode;
-	  *largest=newnode;       /* 'tosort' is larger than all. */
-	}
+        {
+          (*largest)->prev=newnode;
+          *largest=newnode;       /* 'tosort' is larger than all. */
+        }
       newnode->next=tmp;
     }
 }
@@ -802,10 +746,10 @@ gal_linkedlist_smallest_tosll(struct gal_linkedlist_tosll *largest,
   while(tmp!=NULL)
     {
       if(tmp->next==NULL)
-	{
-	  *smallest=tmp;
-	  break;
-	}
+        {
+          *smallest=tmp;
+          break;
+        }
       tmp=tmp->next;
     }
 
@@ -827,7 +771,7 @@ gal_linkedlist_tosll_into_sll(struct gal_linkedlist_tosll *in,
   while(in!=NULL)
     {
       tmp=in->next;
-      add_to_sll(out, in->v);
+      gal_linkedlist_add_to_sll(out, in->v);
       free(in);
       in=tmp;
     }
