@@ -33,11 +33,12 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <gnuastro/fits.h>
 #include <gnuastro/mesh.h>
 #include <gnuastro/qsort.h>
-#include <gnuastro/neighbors.h>
 #include <gnuastro/linkedlist.h>
 #include <gnuastro/statistics.h>
 #include <gnuastro/spatialconvolve.h>
 
+#include "neighbors.h"
+
 
 
 /*
