@@ -24,7 +24,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 #include <stdio.h>
 
-#include <gnuastro/timing.h>
+#include "timing.h"
 
 
 
