@@ -23,7 +23,7 @@
 # basic checks to see if the executable is made or if the defaults
 # file exists (basicchecks.sh is in the source tree).
 prog=subtractsky
-execname=../src/$prog/ast$prog
+execname=../bin/$prog/ast$prog
 img=convolve_spatial_noised.fits
 
 
